SystemOrganization addCategory: #'Seaside-Tests-Environment'!

!WAPackage class methodsFor: '*Seaside-Tests-Environment' stamp: 'jf 10/23/2008 11:45'!
seasideTestsEnvironment
	^ self new
		name: 'Seaside-Tests-Environment';
		description: 'foo';
		addDependency: 'Seaside-Environment';
		addDependency: 'Seaside-Tests-Component';
		addDependency: 'Seaside-Tests-RenderLoop';
		addDependency: 'Seaside-Tests-Session';
		addDependency: 'Seaside-Tests-Canvas';
		yourself! !

WAContextTestCase subclass: #WAStandardFilesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Environment'!

!WAStandardFilesTest methodsFor: 'utilities' stamp: 'jf 10/6/2008 14:55'!
assertFile: aString contentType: aMimeType handler: aHandler symbol: aSymbol library: aLibrary
	| context response |
	context := self requestContextWithUrl: '/seaside/files/', aLibrary name ,'/', aString.
	response := aHandler handleRequest: context.
	self assert: response status = 200.
	self assert: response contentType = aMimeType.
	self assert: response stream contents = (aLibrary perform: aSymbol)! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:53'!
testDeploymentFilenames
	| expected actual |
	expected := #( #externalAnchorsJs #kalseyTabsCss  #miscJs #shortcutsJs #windowCss).
	actual := WAStandardFiles new fileSelectors.
	"VW does not implement #= in Sets"
	self assert: actual size = expected size.
	expected do: [ :each |
		self assert: (expected includes: each)]! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:52'!
testKalseyTabs
	| handler |
	handler := WAFileHandler named: '/seaside/files/'.
	self
		assertFile: 'kalseyTabs.css'
		contentType: WAMimeType textCss
		handler: handler
		symbol: #kalseyTabsCss
		library: WAStandardFiles new! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:53'!
testKalseyTabsCascade
	| handler |
	handler := WAFileHandler named: '/seaside/files/'.
	self
		assertFile: 'kalseyTabs.css'
		contentType: WAMimeType textCss
		handler: handler
		symbol: #kalseyTabsCss
		library: WAStandardFiles new! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:53'!
testLiveUpdate
	| handler |
	handler := WAFileHandler named: '/seaside/files/'.
	self
		assertFile: 'misc.js'
		contentType: 'application/x-javascript' seasideMimeType
		handler: handler
		symbol: #miscJs
		library: WAStandardFiles new! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:53'!
testStandardFiles
	| actual expected |
	actual := WAStandardFiles new filenames.
	expected := #( 'kalseyTabs.css' 'window.css' 'externalAnchors.js' 'misc.js' 'shortcuts.js').
	"VW does not implement #= in Collection because you don't want that"
	self assert: actual size = expected size.
	expected do: [ :each |
		self assert: (actual includes: each) ]! !

!WAStandardFilesTest methodsFor: 'testing' stamp: 'jf 10/6/2008 14:53'!
testWindowCss
	| handler |
	handler := WAFileHandler named: '/seaside/files/'.
	self
		assertFile: 'window.css'
		contentType: WAMimeType textCss
		handler: handler
		symbol: #windowCss
		library: WAStandardFiles new! !

TestCase subclass: #WAEnvironmentDefaultHandlersTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Environment'!

!WAEnvironmentDefaultHandlersTest methodsFor: 'private' stamp: 'jf 10/7/2008 01:45'!
baseName
	^ SeasidePlatformSupport defaultDispatcherName! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'private' stamp: 'jf 10/7/2008 01:42'!
defaultDispatcher
	^ WADispatcher default! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:46'!
testDefaultConfig
	| app |
	app := self defaultDispatcher entryPointAt: 'tests/alltests'.
	self assert: app class == WAApplication.
	self assert: app isApplication.
	self deny: app isDispatcher.
	self deny: app parent isNil.
	self assert: app name = 'alltests'.
	self assert: app basePath = ('/' , self baseName , '/tests/alltests')! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:46'!
testDefaultCounterDirect
	| app |
	app := self defaultDispatcher entryPointAt: 'examples/counter'.
	self assert: app class == WAApplication.
	self assert: app isApplication.
	self deny: app isDispatcher.
	self deny: app parent isNil.
	self assert: app name = 'counter'.
	self assert: app parent name = 'examples'.
	self assert: app basePath = ('/' , self baseName , '/examples/counter')! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:46'!
testDefaultCounterNavigate
	| app |
	app := self defaultDispatcher entryPointAt: 'examples'.
	self assert: app class == WADispatcher.
	self assert: app isDispatcher.
	self deny: app isRoot.
	self deny: app isApplication.
	self deny: app parent isNil.
	self assert: app name = 'examples'.
	self assert: app basePath = ('/' , self baseName , '/examples').
	app := app entryPointAt: 'counter'.
	self assert: app class == WAApplication.
	self assert: app isApplication.
	self deny: app isDispatcher.
	self deny: app parent isNil.
	self assert: app name = 'counter'.
	self assert: app parent name = 'examples'.
	self assert: app basePath = ('/' , self baseName , '/examples/counter')! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:46'!
testDefaultFiles
	| app |
	app := self defaultDispatcher entryPointAt: 'files'.
	self assert: app class == WAFileHandler.
	self deny: app isDispatcher.
	self deny: app isApplication.
	self deny: app parent isNil.
	self assert: app name = 'files'.
	self assert: app basePath = ('/' , self baseName , '/files')! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:44'!
testDefaultRoot
	| app |
	app := self defaultDispatcher.
	self assert: app == WADispatcher default.
	self assert: app class == WADispatcher.
	self assert: app isDispatcher.
	self assert: app isRoot.
	self deny: app isApplication.
	self assert: app parent isNil.
	self assert: app name = self baseName.
	self assert: app basePath = ('/' , self baseName)! !

!WAEnvironmentDefaultHandlersTest methodsFor: 'testing' stamp: 'jf 10/7/2008 01:46'!
testDefaultTests
	| app |
	app := self defaultDispatcher entryPointAt: 'tests'.
	self assert: app class == WADispatcher.
	self assert: app isDispatcher.
	self deny: app isRoot.
	self deny: app isApplication.
	self deny: app parent isNil.
	self assert: app name = 'tests'.
	self assert: app basePath = ('/' , self baseName , '/tests')! !
